@@ -1,4 +1,4 @@
 from .core import get_objects_from_spk, get_connection_from_vault, get_secret_from_vault
 from .sasma import SASMA
-from .sascs import SASCS
+from .sascs import SASCS, SASScoringVS221, SASScoringVS235
 from .bo import parse_dfx
