@@ -1,5 +1,5 @@
 from .core import AbstractSAS
-from .globals import sasma_sasobjsp_host, sasma_sasobjsp_port
+from .globals import sasma_sasobjsp_host, sasma_sasobjsp_port, sasma_workspace
 
 
 class SASMA(AbstractSAS):
@@ -10,7 +10,9 @@ class SASMA(AbstractSAS):
     def __init__(self, user,
                        password,
                        sasobjsp_host=sasma_sasobjsp_host,
-                       sasobjsp_port=sasma_sasobjsp_port,  **kwargs):
+                       sasobjsp_port=sasma_sasobjsp_port,
+                       appserver=sasma_workspace,
+                       **kwargs):
         """
         Establishes sas connection.
         :param user: user, that is used to connect to SASMA.
@@ -25,4 +27,16 @@ class SASMA(AbstractSAS):
                                     sasobjsp_port=sasobjsp_port,
                                     sasobjsp_user=user,
                                     sasobjsp_pass=password,
+                                    appserver=self._is_appserver_valid(appserver),
                                     **kwargs)
+
+    def _is_appserver_valid(self, appsever):
+        allowed_appservers = [sasma_workspace]
+        for existing_appserver in allowed_appservers:
+            if existing_appserver.lower().startswith(appsever.lower()):
+                return appsever
+        else:
+            raise ValueError(f'Appserver must be one of: {allowed_appservers}')
+
+
+
